

{{/*
  Init Container - wait-for-dundasbi-website
*/}}
{{- define "dundas.initcontainer.waitForDundasBiWebsite" -}}
# Wait for Dundas BI 
- name: wait-for-dundasbi-website
  image: {{ include "dundas.env.setupimage" . | quote }}
  command: ['sh', '-c', "/usr/share/dotnet/dotnet /usr/share/dundas/bi/deployment/noversion/DeploymentConsole.dll --container --nonroot || echo 'done'" ]
  imagePullPolicy: {{ include "imagePullPolicy" . }}
  securityContext:
    {{- toYaml .Values.securityContext | nindent 12 }}
  resources:
     {{- toYaml .Values.dundas.bi.setup.resources | nindent 12 }}
  env:
    - name: A180BB4E4AE416297A0AAC7FACFCB751
      value: "ScheduleWait"
    - name: DUNDAS_BI_INTERNAL_APPLICATION_URL
      value: "http://{{ .Release.Name }}-dundas-bi-website{{ if ne .Release.Namespace "default" }}.{{ .Release.Namespace }}{{- end -}}:{{ .Values.dundas.bi.website.port }}/"
	  
{{- end -}}

{{- define "logi.symphony.curl.image" -}}
{{- if ((((((.Values).global).logi).symphony).image).override).curl -}}
{{- ((((((.Values).global).logi).symphony).image).override).curl -}}
{{- else if (((.Values).image).override).curl -}}
{{- (((.Values).image).override).curl -}}
{{- else -}}
{{- "insightsoftware/curl" -}}
{{- end -}}
{{- end -}}

{{/*
  Init Container - wait-for-dundasbi-website
*/}}
{{- define "dundas.initcontainer.waitForComposerConsul" -}}
# Wait for Consul
- name: wait-consul
  image: {{ include "logi.symphony.curl.image" . }}
  command: ["sh", "-c", "counter=0; while [ $counter -lt 60 ]; do if [ $(curl --write-out '%{http_code}' -s -o /dev/null {{ include "composer.discovery.host" . }}:8500/v1/status/leader) -eq 200 ];then echo 'Consul-server reached!';exit 0;else echo 'Consul-server is not reachable..';fi;counter=$((counter+1));sleep 2;done;exit 1"]
  imagePullPolicy: {{ include "imagePullPolicy" . }}
  securityContext:
    {{- toYaml .Values.securityContext | nindent 12 }}
{{- end -}}

{{- define "dundas.initcontainer.commonDbiConfigInit" -}}
# Common DBI Config Init
- name: dbi-config-init
  image: {{ include "dundas.env.setupimage" . | quote }}
  command: ['sh', '-c', "/usr/share/dotnet/dotnet /usr/share/dundas/bi/deployment/noversion/DeploymentConsole.dll --container --nonroot || echo 'done'" ]
  imagePullPolicy: {{ include "imagePullPolicy" . }}
  securityContext:
    {{- toYaml .Values.securityContext | nindent 4 }}
  resources:
    {{- toYaml .Values.dundas.bi.setup.resources | nindent 4 }}
  volumeMounts:    
    - name: dundasshare
      mountPath: /dundas-bi-share/
{{- end -}}

{{/*
  Init Container - storage DBI Config init
*/}}
{{- define "dundas.initcontainer.storageDbiConfigInit" -}}
{{ include "dundas.initcontainer.commonDbiConfigInit" . }}
  env:
    {{ include "dundas.initcontainer.env.commonDbiConfigInit" . }}
    - name: DUNDAS_BI_CONFIG_FILE_PATH
      value: "/usr/share/dundas/bi/Files/Container/www/BIWebStorage/App_Data/dbi.config"
{{- end -}}

{{/*
  Init Container - edc DBI Config init
*/}}
{{- define "dundas.initcontainer.edcDbiConfigInit" -}}
{{ include "dundas.initcontainer.commonDbiConfigInit" . }}
  env:
    {{ include "dundas.initcontainer.env.commonDbiConfigInit" . }}
    - name: DUNDAS_BI_CONFIG_FILE_PATH
      value: "/usr/share/dundas/bi/Files/Container/www/BIWebEDC/App_Data/dbi.config"
{{- end -}}


{{/*
  Init Container - GatewayHub DBI Config init
*/}}
{{- define "dundas.initcontainer.gatewayhubDbiConfigInit" -}}
{{ include "dundas.initcontainer.commonDbiConfigInit" . }}
  env:
    {{ include "dundas.initcontainer.env.commonDbiConfigInit" . }}
    - name: DUNDAS_BI_CONFIG_FILE_PATH
      value: "/usr/share/dundas/bi/Files/Container/www/BIGatewayHub/App_Data/dbi.config"
{{- end -}}

{{- define "dundas.initcontainer.authbridgeDbiConfigInit" -}}
{{ include "dundas.initcontainer.commonDbiConfigInit" . }}
  env:
    {{ include "dundas.initcontainer.env.commonDbiConfigInit" .   }}
    - name: DUNDAS_BI_CONFIG_FILE_PATH
      value: "/usr/share/dundas/bi/Files/Container/www/BIWebsite/App_Data/dbi.config"
{{- end -}}

{{- define "dundas.initcontainer.env.commonDbiConfigInit" -}}

    # Common DBI Config Env
    - name: CHECK_FOR_ACTION
      value: "DbiConfig"
    {{ if .Values.dundas.bi.appDb.express }}
    - name: POSTGRES_PASSWORD
      valueFrom:
        secretKeyRef:
          name: {{ .Release.Name }}
          key: postgres-password
    {{ end }}
    {{- include "dundas.env.dundasBiAppDbConnString" . | indent 4 }}
	{{- include "dundas.env.appStorage" . | indent 4 }}
	{{- include "dundas.env.deploymentMode" . | indent 4 }}
{{- end -}}

